function x_hat_ebm = frebme(ebme, y)
%HEBME Full rank ellipsoidal blind minimax estimator.
%   X_HAT_FREBM = FREBME(PREP, Y) produces the full rank ellipsoidal blind
%   minimax estimatation of X, solving the system Y = H*X + W, where W is
%   white Gaussian noise.
%   Calculation is based in part on precalculated data PREP.
%
%   Number of ignored measurements K is limited to zero.
%
%   See also EBME_PREP, SBME, SBME_PREP.

%   Asaf Elron and Guy Leibovitz, 2008.
%   Based on Leibovitz, Elron, Ben-Haim & Eldar, Recursive Blind Minimax
%   Estimation: Improving MSE over Recursive Least Squares", IEEEI 2008.

%% calculate x_hat_ls and its norm
x_hat_ls = leastsq(ebme.LS, y); % calculate the least squares estimation
Q_norm_squared = x_hat_ls' * ebme.Q_to_power_b * x_hat_ls; % calculate the squared Q^b-norm of the least squares estimation

%% handle trivial estimation possibility
if (Q_norm_squared == 0) % is the least squares estimation the trivial estimation?
    x_hat_ebm = 0; % return trivial estimator
    return; % we're done now
end;

%% set number of measurements to ignore k to 0
k = 0;
alpha = ebme.r1_per_k(k+1) / (Q_norm_squared + ebme.r2_per_k(k+1));

%% calculate frEBME estimation
x_hat_ebm = ebme.V * diag( max(0, 1 - alpha * ebme.sigmas_to_power_half_b) ) * ebme.V' * x_hat_ls; % (19)

end
