function x_hat_sbm = sbme(varargin)
%SBME Spherical blind minimax estimator.
%   X_HAT_SBM = SBME(PREP, Y) produces the spherical blind minimax
%   estimatation of X, solving the system Y = H*X + W, where W is coloured
%   Gaussian noise.
%   Calculation is based in part on precalculated data PREP.
%
%   X_HAT_SBM = SBME(LS, E0, Y) produces the same result, where LS is the
%   least squares estimator and E0 is the least squares mean squared error.
%
%   See also SBME_PREP, EBME, EBME_PREP.

%   Asaf Elron and Guy Leibovitz, 2008.
%   Based on Ben-Haim & Eldar, Blind Minimax Estimation", IEEE TIT, 2007.

%% facilitate both calling formats
error(nargchk(2, 3, nargin, 'struct'));
if (nargin == 2)
    % preperation data given inside a struct
	LS = varargin{1}.LS;
    epsilon0 = varargin{1}.epsilon0;
    y = varargin{2};
else
    % preperation data given explicitly
    LS = varargin{1};
    epsilon0 = varargin{2};
    y = varargin{3};
end;

%% calculate stuff
x_hat_ls = leastsq(LS, y); % get LS estimation on measurements

L_square = norm_squared(x_hat_ls); % calculate x_hat_ls's squared norm

x_hat_sbm = L_square / (L_square + epsilon0) * x_hat_ls; % calculate SBM estimation (7)

end
