function jsrls_data = jsrls_init(parameter_count, delta, lambda, noise_variance)
%JSRLS_INIT Initialize James-Stein Recursive Least Squares estimator.
%   JSRLS_DATA = JSRLS_INIT(PARAMETER_COUNT, DELTA, LAMBDA, NOISE_VAR) is a
%   struct containing preperatory data for recursively calculating the 
%   James-Stein recursive least squares estimator, to be used with JSRLS().
%   PARAMETER_COUNT is the number of paramters to estimate. DELTA is either
%   the regularization initialization parameter [1] or initial estimation
%   data created by INITIAL_ESTIMATION(). LAMBDA is the forgetting factor.
%   NOISE_VAR is the variance of the additive noise.
%
%   [1] Haykin, Adaptive Filter Theory, 4th ed., pp. 437.
%
%   See also JSRLS.

%   Asaf Elron and Guy Leibovitz, 2008.
%   Based on Manton et al., JamesStein State Filtering Algorithms", IEEE
%   SP, 1998.

%% 

% initialize RLS
rls_data = rls_init(parameter_count, delta, lambda, noise_variance);

% generate tracking struct
jsrls_data = struct('rls_data', rls_data, ...
                    'estimation', rls_data.estimation);

end
