function delta = initial_estimation(H, Y, lambda)
%INITIAL_ESTIMATION Initial estimation data for initialization of RLS.
%   DELTA = INITIAL_ESTIMATION(H, Y, LAMBDA) is a struct containing
%   initialization data to be used with RLS_INIT().
%
%   Packs the least squares estimation based on the model matrix H and the
%   measurements Y, as well as the covariance matrix P, into the optional
%   initialization structure used by RLS_INIT().
%
%   LABMDA is the exponential forgetting factor. If not specified, a
%   forgetting factor of 1 is assumed.
%
%   See also: RLS_INIT, RLS.

%   Asaf Elron and Guy Leibovitz, 2008.

% check input
if (nargin < 3) % was the forgetting factor not specified?
    lambda = 1; % assume 1
end;

% perform initial estimation
[initial_ls_data, Qinv] = leastsq_prep(H, forget(size(H, 1), lambda^-1)*eye(size(H, 1)));
initial_estimation = leastsq(initial_ls_data, Y);

% pack in delta
delta = struct('Qinv', Qinv, ...
               'initial_estimation', initial_estimation);

end
