function [LS, Qinv, epsilon0] = leastsq_prep(H, Cw)
%LEASTSQ_PREP Prepare generalized least squares estimator.
%   LS = LEASTSQ_PREP(H, Cw) is the LS estimator matrix.
%   The measurement transform H is assumed to be of full rank and the noise
%   covariance Cw is assumed to be positive definite.
%
%   [LS, Qinv] = LEASTSQ_PREP(H, Cw) also returns Qinv = (H* Cw^-1 H)^-1
%   for further calculations.
%
%   [LS, Qinv, E0] = LEASTSQ_PREP(H, Cw) also returns E0 as the LS
%   estimator's MSE.
%
%   For more general, rank deficient problems, refer to the MATLAB function
%   LSCOV().
%
%   See also LEASTSQ, LSCOV.

%   Asaf Elron and Guy Leibovitz, 2008.
 
Qinv = (H' * Cw ^-1 * H) ^-1;
LS = Qinv * H' * Cw ^-1; % generate least squares estimation matrix
epsilon0 = trace(Qinv);

end
